@@ -75,14 +75,14 @@ class ServerOS(DefaultOS):
                     iffile.write('iface {0} inet static\n'.format(ifname))
                     iffile.write('\taddress {0}\n'.format(x['ip']))
                     iffile.write('\tnetmask {0}\n'.format(x['netmask']))
-                    if 'gateway' in iface and iface['gateway']:
+                    if iface.get('gateway'):
                         iffile.write(
                             '\tgateway {0}\n'.format(
                                 iface['gateway']
                             )
                         )
 
-                    if 'dns' in iface and iface['dns']:
+                    if iface.get('dns'):
                         iffile.write(
                             '\tdns-nameservers {0}\n'.format(
                                 ' '.join(iface['dns'])
@@ -119,7 +119,7 @@ class ServerOS(DefaultOS):
                     iffile.write('\taddress {0}\n'.format(x['ip']))
                     iffile.write('\tnetmask {0}\n'.format(x['netmask']))
 
-            if 'ip6s' in iface and iface['ip6s']:
+            if iface.get('ip6s'):
                 for count, ip_info in enumerate(iface['ip6s']):
                     if count == 0:
                         iffile.write(
@@ -164,28 +164,27 @@ class ServerOS(DefaultOS):
         }
         for ifname, iface in ifaces.items():
             temp_net = {'addresses': [], 'dhcp4': False}
-
-            ipv4_details = iface['ips'][0]
-            temp_net['addresses'].append(
-                '{0}/{1}'.format(
-                    ipv4_details.get('ip'),
-                    utils.netmask_to_prefix(ipv4_details.get('netmask'))
+            for temp_ip in iface['ips']:
+                temp_net['addresses'].append(
+                    '{0}/{1}'.format(
+                        temp_ip.get('ip'),
+                        utils.netmask_to_prefix(temp_ip.get('netmask'))
+                    )
                 )
-            )
 
             if iface.get('gateway'):
                 temp_net['gateway4'] = iface.get('gateway')
 
             if iface.get('ip6s'):
-                ipv6_details = iface['ip6s'][0]
                 temp_net['dhcp6'] = False
                 temp_net['gateway6'] = iface.get('gateway_v6')
-                temp_net['addresses'].append(
-                    '{0}/{1}'.format(
-                        ipv6_details.get('ip'),
-                        ipv6_details.get('netmask')
+                for temp_ipv6 in iface['ip6s']:
+                    temp_net['addresses'].append(
+                        '{0}/{1}'.format(
+                            temp_ipv6.get('ip'),
+                            temp_ipv6.get('netmask')
+                        )
                     )
-                )
 
             if iface.get('dns'):
                 temp_net['nameservers'] = {
@@ -237,13 +236,8 @@ class ServerOS(DefaultOS):
         if use_netplan:
             # Setup netplan config file
             self._setup_netplan(ifaces)
-        else:
-            # Setup interfaces file
-            self._setup_loopback()
-            for ifname, iface in ifaces.items():
-                self._setup_interfaces(ifname, iface)
 
-        if use_netplan:
+            # Apply the netplan policy
             p = Popen(
                 ['netplan', 'apply'],
                 stdout=PIPE,
@@ -257,6 +251,11 @@ class ServerOS(DefaultOS):
                     'Error applying netplan: {0}'.format(str(err))
                 )
         else:
+            # Setup interfaces file
+            self._setup_loopback()
+            for ifname, iface in ifaces.items():
+                self._setup_interfaces(ifname, iface)
+
             # Loop through the interfaces and restart networking
             for ifname in ifaces.keys():
                 p = Popen(
